Default implementation of the high level protocol given a binary backing implementation as defined in the storage-layout namespace.
Default implementation of the high level protocol given a binary backing implementation as defined in the storage-layout namespace.
One of these protocols must be implemented by each store to provide low level access depending on the low-level storage layout chosen. Stores can support multiple layouts.
One of these protocols must be implemented by each store to provide low level access depending on the low-level storage layout chosen. Stores can support multiple layouts.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |