Default implementation of the high level protocol given a binary backing implementation as defined in the storage-layout namespace.
Default implementation of the high level protocol given a binary backing implementation as defined in the storage-layout namespace.
(connect-default-store backing
{:keys [default-serializer serializers read-handlers
write-handlers buffer-size config opts]
:or {default-serializer :FressianSerializer
read-handlers (atom {})
write-handlers (atom {})
buffer-size (* 1024 1024)
opts {:sync? false}}})Create general store in given base of backing store.
Create general store in given base of backing store.
(delete-blob backing env)Remove/Delete key-value pair of backing store by given key. If success it will return true.
Remove/Delete key-value pair of backing store by given key. If success it will return true.
(io-operation {:keys [backing]}
serializers
read-handlers
write-handlers
{:keys [key-vec operation default-serializer sync? overwrite?
config]
:as env})Read/Write blob. For better understanding use the flow-chart of konserve.
Read/Write blob. For better understanding use the flow-chart of konserve.
(list-keys {:keys [backing]}
serializers
read-handlers
write-handlers
{:keys [sync? config] :as env})Return all keys in the store.
Return all keys in the store.
(prepare-multi-assoc backing
serializers
read-handlers
write-handlers
{:keys [kvs meta-up-fn default-serializer compressor
encryptor version config]
:as env})Prepares multiple key-value pairs for writing to the backing store. Handles serialization, metadata updates, and key translation.
Prepares multiple key-value pairs for writing to the backing store. Handles serialization, metadata updates, and key translation.
(read-blob blob
read-handlers
serializers
{:keys [sync? operation locked-cb config _store-key] :as env})Read meta, edn or binary from blob.
Read meta, edn or binary from blob.
(update-blob backing
store-key
serializer
write-handlers
{:keys [key-vec compressor encryptor up-fn up-fn-meta config
operation input sync? version]
:as env}
[old-meta old-value])This function writes first the meta-size, then the meta-data and then the actual updated data into the underlying backing store.
This function writes first the meta-size, then the meta-data and then the actual updated data into the underlying backing store.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |