Address globally aggregated immutable key-value store(s). Does not support serialization.
Address globally aggregated immutable key-value store(s). Does not support serialization.
(connect-mem-store id opts)Connect to an existing memory store by ID. Returns nil if not found.
Args: id - String ID of the store to connect to opts - Options map with :sync? boolean
Returns: Store instance if found, nil otherwise (or channel in async mode)
Connect to an existing memory store by ID. Returns nil if not found. Args: id - String ID of the store to connect to opts - Options map with :sync? boolean Returns: Store instance if found, nil otherwise (or channel in async mode)
(delete-mem-store id)Delete a memory store from the registry by ID.
Args: id - String ID of the store to delete
Returns: true if store was deleted, false if not found
Delete a memory store from the registry by ID. Args: id - String ID of the store to delete Returns: true if store was deleted, false if not found
Global registry of memory stores by ID. Allows multiple parts of an application to connect to the same memory store.
Global registry of memory stores by ID. Allows multiple parts of an application to connect to the same memory store.
(new-mem-store)(new-mem-store init-atom)(new-mem-store init-atom opts)Create in memory store. Binaries are not properly locked yet and the read and write-handlers are dummy ones for compatibility.
The store will be registered globally by :id and can be retrieved later via connect-mem-store.
Options: :id - String UUID for the store (required) :sync? - Boolean for sync/async operation (default false)
Create in memory store. Binaries are not properly locked yet and the read and write-handlers are dummy ones for compatibility. The store will be registered globally by :id and can be retrieved later via connect-mem-store. Options: :id - String UUID for the store (required) :sync? - Boolean for sync/async operation (default false)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |