(check-and-create-backing-store base)Helper Function to Check if Base is not writable
Helper Function to Check if Base is not writable
(check-and-create-backing-store-async base)Helper Function to Check if Base is not writable
Helper Function to Check if Base is not writable
(connect-fs-store
path
&
{:keys [detect-old-file-schema? ephemeral? config]
:or {detect-old-file-schema? false
ephemeral? (fn [pathstr]
(some (fn* [p1__54497#] (re-matches p1__54497# pathstr))
[#"\.nfs.*"]))}
:as params})Create Filestore in given path. Optional serializer, read-handlers, write-handlers, buffer-size and config (for fsync) can be changed.
k/bget callback gets different args depending on :sync?
{:input-stream <fs.readStream>} akin to
the same call on the JVM filestore impl. These streams are opened to the
same fd that konserve is managing for the blob, so users should not call
destroy() or it will raise an error{:blob <js/Buffer>}{:base path :serializer fressian-serializer :read-handlers empty :write-handlers empty :buffer-size 1 MB :config config}
Create Filestore in given path.
Optional serializer, read-handlers, write-handlers, buffer-size and config (for fsync) can be changed.
+ the `k/bget` callback gets different args depending on `:sync?`
- async bget callbacks recieve `{:input-stream <fs.readStream>}` akin to
the same call on the JVM filestore impl. These streams are opened to the
same fd that konserve is managing for the blob, so users should not call
destroy() or it will raise an error
- sync bget callbacks are called with `{:blob <js/Buffer>}`
{:base path
:serializer fressian-serializer
:read-handlers empty
:write-handlers empty
:buffer-size 1 MB
:config config} (count-konserve-keys dir)Counts konserve files in the directory.
Counts konserve files in the directory.
(delete-store base)Permanently deletes the base of the store with all files.
Permanently deletes the base of the store with all files.
(delete-store-async base)Permanently deletes the base of the store with all files.
Permanently deletes the base of the store with all files.
(list-files directory)(list-files directory ephemeral?)Lists all files on the first level of a directory.
Lists all files on the first level of a directory.
(open-async-file-channel path)(open-async-file-channel path {flags :flags})(store-exists? base)Check if underlying store already exists.
Check if underlying store already exists.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |