konserve.utils


*default-sync-translation*clj/s

source

async+syncclj/smacro

(async+sync sync? async->sync async-code)
source

invert-mapclj/s

(invert-map m)
source

invoke-write-hooks!clj/s

(invoke-write-hooks! store hook-event)

Invoke all registered write hooks with the operation details. Hooks are called synchronously after a successful write.

Invoke all registered write hooks with the operation details.
Hooks are called synchronously after a successful write.
sourceraw docstring

meta-updateclj/s

(meta-update key type old)

Metadata has following 'edn' format {:key 'The stored key' :type 'The type of the stored value binary or edn' :last-write Date timestamp in milliseconds.} Returns the meta value of the stored key-value tuple. Returns metadata if the key value not exist, if it does it will update the last-write to date now.

Metadata has following 'edn' format
{:key 'The stored key'
 :type 'The type of the stored value binary or edn'
 :last-write Date timestamp in milliseconds.}
Returns the meta value of the stored key-value tuple. Returns metadata if the key
value not exist, if it does it will update the last-write to date now. 
sourceraw docstring

multi-key-capable?clj/s

(multi-key-capable? store)

Checks whether the store supports multi-key operations.

This function is used by the high-level API to determine if a store supports multi-key operations.

Checks whether the store supports multi-key operations.

This function is used by the high-level API to determine if a store supports multi-key operations.
sourceraw docstring

nowclj/s

(now)
source

with-promiseclj/smacro

(with-promise sym & body)
source

write-hooks-capable?clj/s

(write-hooks-capable? store)

Checks whether the store supports write hooks.

This function is used by the high-level API and compliance tests to determine if a store supports the PWriteHookStore protocol.

Checks whether the store supports write hooks.

This function is used by the high-level API and compliance tests to determine
if a store supports the PWriteHookStore protocol.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries